@@ -37,6 +37,10 @@ class Event(Resource):
         event_manager.publish(channel, message)
         return application.make_ok_response()
 
+    def delete(self):
+        db_server = application.server['db']
+        db_server.reset()
+        return application.make_ok_response()
 
 class Channel(Resource):
 
