@@ -1,9 +1,11 @@
 import re
 import uuid
 import json
+import datetime
 import traceback
 from pathlib import Path
 from urllib.parse import urlparse
+from collections import OrderedDict
 from lyrebird.log import get_logger
 from jinja2 import Template
 from lyrebird.application import config
@@ -21,10 +23,9 @@ class DataManager:
         self.root_path: Path = None
         self.display_data_map = {}
         self.id_map = {}
-        self.activated_data = {}
+        self.activated_data = OrderedDict()
         self.activated_group = {}
-        self.secondary_activated_data = {}
-        self.LEVEL_SECONDARY_ACTIVATED = 2
+        self.LEVEL_SUPER_ACTIVATED = 2
         self.clipboard = None
         self.save_to_group_id = None
         self.tmp_group = {'id': 'tmp_group', 'type': 'group', 'name': 'tmp-group', 'label': [], 'children': []}
@@ -107,52 +108,62 @@ class DataManager:
 
         return self.display_data_map
 
-    def activate(self, _id):
+    def activate(self, search_id):
         """
         Activite data by id
         """
         if not self.root:
             raise RootNotSet
-        _node = self.id_map.get(_id)
-        if _node:
-            self._activate(_node)
-        else:
-            raise IDNotFound(f'ID:{_id}')
-        self._activate_super_node(_node, level_lefted=self.LEVEL_SECONDARY_ACTIVATED)
+        _node = self._adapter._get_activate_group(search_id)
+        if not _node:
+            raise IDNotFound(f'ID:{search_id}')
+
+        _id = _node['id']
+        node_id_list = self._collect_activate_node(_node, level_lefted=self.LEVEL_SUPER_ACTIVATED)
+
+        ordered_data_id = []
+        for node_id in node_id_list:
+            activated_node = self.id_map.get(node_id)
+            ordered_data_id += self._collect_activate_data(activated_node)
+        data_list = self._adapter._load_data_by_query({'id': ordered_data_id})
+
+        data_map = {d['id']: d for d in data_list}
+        self.activated_data.update({i: data_map[i] for i in ordered_data_id if data_map.get(i)})
         self.activated_group[_id] = _node
 
-    def _activate_super_node(self, node, level_lefted=1):
+    def _collect_activate_node(self, node, level_lefted=1):
+        id_list = [node['id']]
         if level_lefted <= 0:
-            return
+            return id_list
         if not node.get('super_id'):
-            return
-        _secondary_search_node_id = node.get('super_id')
-        _secondary_search_node = self.id_map.get(_secondary_search_node_id)
-        if not _secondary_search_node:
-            raise IDNotFound(f'Secondary search node ID: {_secondary_search_node_id}')
-        self._activate(_secondary_search_node, secondary_search=True)
-        self._activate_super_node(_secondary_search_node, level_lefted=level_lefted-1)
+            return id_list
+        if node.get('super_id') == node['id']:
+            raise SuperIdCannotBeNodeItself(node['id'])
 
-    def _activate(self, node, secondary_search=False):
+        _super_id = node.get('super_id')
+        _super_node = self.id_map.get(_super_id)
+        if not _super_node:
+            raise IDNotFound(f'Super node ID: {_super_node}')
+
+        id_list.extend(self._collect_activate_node(_super_node, level_lefted=level_lefted-1))
+        return id_list
+
+    def _collect_activate_data(self, node):
+        id_list = []
         if node.get('type', '') == 'data':
-            _mock_data = self._adapter._load_data(node['id'])
-            if _mock_data:
-                if not secondary_search:
-                    self.activated_data[node['id']] = _mock_data
-                else:
-                    self.secondary_activated_data[node['id']] = _mock_data
+            return [node['id']]
         elif node.get('type', '') == 'group':
             if 'children' in node:
                 for child in node['children']:
-                    self._activate(child, secondary_search=secondary_search)
+                    id_list.extend(self._collect_activate_data(child))
+        return id_list
 
     def deactivate(self):
         """
         Clear activated data
         """
-        self.activated_data = {}
+        self.activated_data = OrderedDict()
         self.activated_group = {}
-        self.secondary_activated_data = {}
 
     def reactive(self):
         origin_activated_group = self.activated_group
@@ -169,11 +180,7 @@ class DataManager:
             _data = self.activated_data[_data_id]
             if self._is_match_rule(flow, _data.get('rule')):
                 _matched_data.append(_data)
-        if len(_matched_data) <= 0:
-            for _data_id in self.secondary_activated_data:
-                _data = self.secondary_activated_data[_data_id]
-                if self._is_match_rule(flow, _data.get('rule')):
-                    _matched_data.append(_data)
+                break
 
         for response_data in _matched_data:
             if 'response' not in response_data:
@@ -190,7 +197,9 @@ class DataManager:
         # TODO render mock data before response, support more functions
         params = {
             'ip': config.get('ip'),
-            'port': config.get('mock.port')
+            'port': config.get('mock.port'),
+            'today': datetime.date.today(),
+            'now':  datetime.datetime.now()
         }
 
         try:
@@ -262,8 +271,8 @@ class DataManager:
             # TODO remove it with inspector frontend
             data['request'] = dict(raw_data['request'])
 
-            _data_name = self._adapter._get_data_name(data)
-            _data_rule = self._adapter._get_data_rule(data['request'])
+            _data_name = data['name'] if data.get('name') else self._adapter._get_data_name(data)
+            _data_rule = data['rule'] if data.get('rule') else self._adapter._get_data_rule(data['request'])
             if 'data' in data['request']:
                 data['request']['data'] = self._flow_data_2_str(data['request']['data'])
         else:
@@ -686,6 +695,10 @@ class DataObjectCannotContainAnyOtherObject(Exception):
     pass
 
 
+class SuperIdCannotBeNodeItself(Exception):
+    pass
+
+
 class DataObjectSouldBeADict(Exception):
     pass
 
